==> nhc98_1.16.orig.tar.gz: nhc98-1.16/src/prelude/BinArray/RUBA.z.c <==
#include "newmacros.h"
#include "runtime.h"

#define FN_NHC_46BinArray_46hs_95rUBA_35	((void*)startLabel+12)
#define CT_v200	((void*)startLabel+44)
#define F0_NHC_46BinArray_46hs_95rUBA_35	((void*)startLabel+52)
#define FN_NHC_46BinArray_46hs_95rUBA	((void*)startLabel+64)
#define CT_v202	((void*)startLabel+88)
#define CF_NHC_46BinArray_46hs_95rUBA	((void*)startLabel+96)
#define CT_v204	((void*)startLabel+156)
#define FN_LAMBDA197	((void*)startLabel+192)
#define CT_v206	((void*)startLabel+216)
#define F0_LAMBDA197	((void*)startLabel+224)
#define ST_v201	((void*)startLabel+232)
#define ST_v199	((void*)startLabel+253)
#define ST_v203	((void*)startLabel+275)
#define ST_v205	((void*)startLabel+293)
extern Node TM_NHC_46BinArray[];
void FR_NHC_46BinArray_46hs_95rUBA_35(void);
extern Node TM_NHC_46BinArray[];
extern Node FN_NHC_46Internal_46_95mkIOok2[];
extern Node TM_NHC_46BinArray[];
extern Node FN_NHC_46Internal_46_95apply2[];
extern Node FN_Prelude_46Monad_46NHC_46Internal_46IO_46_62_62_61[];
extern Node TMSUB_NHC_46BinArray[];
extern Node FN_Prelude_46Monad_46NHC_46Internal_46IO_46return[];

static Node startLabel[] = {
  bytes2word(0,0,2,0)
, bytes2word(1,1,0,2)
, useLabel(CT_v200)
,	/* FN_NHC_46BinArray_46hs_95rUBA_35: (byte 0) */
  useLabel(TM_NHC_46BinArray)
, bytes2word(PUSH_ARG_I1,EVAL,POP_I1,PUSH_ARG_I2)
, bytes2word(EVAL,POP_I1,PRIMITIVE,NOP)
, useLabel(FR_NHC_46BinArray_46hs_95rUBA_35)
, bytes2word(RETURN_EVAL,ENDCODE,0,0)
, bytes2word(0,0,0,0)
, 110022
, useLabel(ST_v199)
,	/* CT_v200: (byte 0) */
  HW(0,2)
, 0
,	/* F0_NHC_46BinArray_46hs_95rUBA_35: (byte 0) */
  CAPTAG(useLabel(FN_NHC_46BinArray_46hs_95rUBA_35),2)
, bytes2word(0,0,0,0)
, useLabel(CT_v202)
,	/* FN_NHC_46BinArray_46hs_95rUBA: (byte 0) */
  useLabel(TM_NHC_46BinArray)
, bytes2word(NEEDHEAP_I32,PUSH_HEAP,HEAP_CVAL_I3,HEAP_CVAL_I4)
, bytes2word(RETURN_EVAL,ENDCODE,0,0)
, bytes2word(0,0,0,0)
, 110022
, useLabel(ST_v201)
,	/* CT_v202: (byte 0) */
  HW(2,0)
, 0
,	/* CF_NHC_46BinArray_46hs_95rUBA: (byte 0) */
  VAPTAG(useLabel(FN_NHC_46BinArray_46hs_95rUBA))
, VAPTAG(useLabel(FN_NHC_46Internal_46_95mkIOok2))
, useLabel(F0_NHC_46BinArray_46hs_95rUBA_35)
, bytes2word(0,0,2,0)
, bytes2word(1,1,0,2)
, useLabel(CT_v204)
,};
Node FN_NHC_46BinArray_46rUBA[] = {
  useLabel(TM_NHC_46BinArray)
, bytes2word(NEEDHEAP_I32,HEAP_CVAL_I3,HEAP_CVAL_I4,HEAP_OFF_N1)
, bytes2word(2,HEAP_ARG_ARG,1,2)
, bytes2word(HEAP_CVAL_I5,PUSH_HEAP,HEAP_CVAL_P1,6)
, bytes2word(HEAP_OFF_N1,6,HEAP_OFF_N1,3)
, bytes2word(RETURN_EVAL,ENDCODE,0,0)
, bytes2word(0,0,0,0)
, 140001
, useLabel(ST_v203)
,	/* CT_v204: (byte 0) */
  HW(4,2)
, 0
,};
Node F0_NHC_46BinArray_46rUBA[] = {
  CAPTAG(useLabel(FN_NHC_46BinArray_46rUBA),2)
, VAPTAG(useLabel(FN_NHC_46BinArray_46hs_95rUBA))
, VAPTAG(useLabel(FN_NHC_46Internal_46_95apply2))
, CAPTAG(useLabel(FN_LAMBDA197),1)
, VAPTAG(useLabel(FN_Prelude_46Monad_46NHC_46Internal_46IO_46_62_62_61))
, bytes2word(1,0,0,1)
, useLabel(CT_v206)
,	/* FN_LAMBDA197: (byte 0) */
  useLabel(TMSUB_NHC_46BinArray)
, bytes2word(NEEDHEAP_I32,PUSH_HEAP,HEAP_CVAL_I3,HEAP_ARG)
, bytes2word(1,RETURN_EVAL,ENDCODE,0)
, bytes2word(0,0,0,0)
, 150014
, useLabel(ST_v205)
,	/* CT_v206: (byte 0) */
  HW(1,1)
, 0
,	/* F0_LAMBDA197: (byte 0) */
  CAPTAG(useLabel(FN_LAMBDA197),1)
, VAPTAG(useLabel(FN_Prelude_46Monad_46NHC_46Internal_46IO_46return))
,	/* ST_v201: (byte 0) */
  bytes2word(78,72,67,46)
, bytes2word(66,105,110,65)
, bytes2word(114,114,97,121)
, bytes2word(46,104,115,95)
, bytes2word(114,85,66,65)
,	/* ST_v199: (byte 1) */
  bytes2word(0,78,72,67)
, bytes2word(46,66,105,110)
, bytes2word(65,114,114,97)
, bytes2word(121,46,104,115)
, bytes2word(95,114,85,66)
,	/* ST_v203: (byte 3) */
  bytes2word(65,35,0,78)
, bytes2word(72,67,46,66)
, bytes2word(105,110,65,114)
, bytes2word(114,97,121,46)
, bytes2word(114,85,66,65)
,	/* ST_v205: (byte 1) */
  bytes2word(0,78,72,67)
, bytes2word(46,66,105,110)
, bytes2word(65,114,114,97)
, bytes2word(121,46,114,85)
, bytes2word(66,65,58,49)
, bytes2word(53,58,49,52)
, bytes2word(0,0,0,0)
,};

#include <haskell2c.h>
#include <HsFFI.h>

/* foreign import ccall "hs_rUBA" NHC.BinArray.hs_rUBA# 2 :: FFI.ForeignObj -> Prelude.Int -> Prelude.Int */
extern HsInt hs_rUBA(void*,HsInt);
#ifdef PROFILE
static SInfo pf_hs_rUBA = {"NHC.BinArray","NHC.BinArray.hs_rUBA#","Prelude.Int"};
#endif
C_HEADER(FR_NHC_46BinArray_46hs_95rUBA_35) {
  NodePtr nodeptr;
  HsInt result;
  void* arg1;
  HsInt arg2;
  nodeptr = C_GETARG1(1);
  IND_REMOVE(nodeptr);
  arg1 = (void*)derefForeignObj((ForeignObj*)GET_INT_VALUE(nodeptr));
  nodeptr = C_GETARG1(2);
  IND_REMOVE(nodeptr);
  arg2 = (HsInt)GET_INT_VALUE(nodeptr);

  result = hs_rUBA(arg1,arg2);

  nodeptr = nhc_mkInt(result);
  INIT_PROFINFO(nodeptr,&pf_hs_rUBA);
  C_RETURN(nodeptr);
}

==> nhc98_1.18.orig.tar.gz: nhc98-1.18/src/prelude/BinArray/RUBA.z.c <==
#include "newmacros.h"
#include "runtime.h"

#define FN_NHC_46BinArray_46hs_95rUBA_35	((void*)startLabel+12)
#define CT_v204	((void*)startLabel+44)
#define F0_NHC_46BinArray_46hs_95rUBA_35	((void*)startLabel+52)
#define FN_NHC_46BinArray_46hs_95rUBA	((void*)startLabel+64)
#define CT_v206	((void*)startLabel+88)
#define CF_NHC_46BinArray_46hs_95rUBA	((void*)startLabel+96)
#define CT_v208	((void*)startLabel+156)
#define FN_LAMBDA201	((void*)startLabel+192)
#define CT_v210	((void*)startLabel+216)
#define F0_LAMBDA201	((void*)startLabel+224)
#define ST_v205	((void*)startLabel+232)
#define ST_v203	((void*)startLabel+253)
#define ST_v207	((void*)startLabel+275)
#define ST_v209	((void*)startLabel+293)
extern Node TM_NHC_46BinArray[];
void FR_NHC_46BinArray_46hs_95rUBA_35(void);
extern Node FN_NHC_46Internal_46_95mkIOok2[];
extern Node FN_NHC_46Internal_46_95apply2[];
extern Node FN_Prelude_46Monad_46NHC_46Internal_46IO_46_62_62_61[];
extern Node TMSUB_NHC_46BinArray[];
extern Node FN_Prelude_46Monad_46NHC_46Internal_46IO_46return[];

static Node startLabel[] = {
  bytes2word(0,0,2,0)
, bytes2word(1,1,0,2)
, useLabel(CT_v204)
,	/* FN_NHC_46BinArray_46hs_95rUBA_35: (byte 0) */
  useLabel(TM_NHC_46BinArray)
, bytes2word(PUSH_ARG_I1,EVAL,POP_I1,PUSH_ARG_I2)
, bytes2word(EVAL,POP_I1,PRIMITIVE,NOP)
, useLabel(FR_NHC_46BinArray_46hs_95rUBA_35)
, bytes2word(RETURN_EVAL,ENDCODE,0,0)
, bytes2word(0,0,0,0)
, 110001
, useLabel(ST_v203)
,	/* CT_v204: (byte 0) */
  HW(0,2)
, 0
,	/* F0_NHC_46BinArray_46hs_95rUBA_35: (byte 0) */
  CAPTAG(useLabel(FN_NHC_46BinArray_46hs_95rUBA_35),2)
, bytes2word(0,0,0,0)
, useLabel(CT_v206)
,	/* FN_NHC_46BinArray_46hs_95rUBA: (byte 0) */
  useLabel(TM_NHC_46BinArray)
, bytes2word(NEEDHEAP_I32,PUSH_HEAP,HEAP_CVAL_I3,HEAP_CVAL_I4)
, bytes2word(RETURN_EVAL,ENDCODE,0,0)
, bytes2word(0,0,0,0)
, 110001
, useLabel(ST_v205)
,	/* CT_v206: (byte 0) */
  HW(2,0)
, 0
,	/* CF_NHC_46BinArray_46hs_95rUBA: (byte 0) */
  VAPTAG(useLabel(FN_NHC_46BinArray_46hs_95rUBA))
, VAPTAG(useLabel(FN_NHC_46Internal_46_95mkIOok2))
, useLabel(F0_NHC_46BinArray_46hs_95rUBA_35)
, bytes2word(0,0,2,0)
, bytes2word(1,1,0,2)
, useLabel(CT_v208)
,};
Node FN_NHC_46BinArray_46rUBA[] = {
  useLabel(TM_NHC_46BinArray)
, bytes2word(NEEDHEAP_I32,HEAP_CVAL_I3,HEAP_CVAL_I4,HEAP_OFF_N1)
, bytes2word(2,HEAP_ARG_ARG,1,2)
, bytes2word(HEAP_CVAL_I5,PUSH_HEAP,HEAP_CVAL_P1,6)
, bytes2word(HEAP_OFF_N1,6,HEAP_OFF_N1,3)
, bytes2word(RETURN_EVAL,ENDCODE,0,0)
, bytes2word(0,0,0,0)
, 140001
, useLabel(ST_v207)
,	/* CT_v208: (byte 0) */
  HW(4,2)
, 0
,};
Node F0_NHC_46BinArray_46rUBA[] = {
  CAPTAG(useLabel(FN_NHC_46BinArray_46rUBA),2)
, VAPTAG(useLabel(FN_NHC_46BinArray_46hs_95rUBA))
, VAPTAG(useLabel(FN_NHC_46Internal_46_95apply2))
, CAPTAG(useLabel(FN_LAMBDA201),1)
, VAPTAG(useLabel(FN_Prelude_46Monad_46NHC_46Internal_46IO_46_62_62_61))
, bytes2word(1,0,0,1)
, useLabel(CT_v210)
,	/* FN_LAMBDA201: (byte 0) */
  useLabel(TMSUB_NHC_46BinArray)
, bytes2word(NEEDHEAP_I32,PUSH_HEAP,HEAP_CVAL_I3,HEAP_ARG)
, bytes2word(1,RETURN_EVAL,ENDCODE,0)
, bytes2word(0,0,0,0)
, 150014
, useLabel(ST_v209)
,	/* CT_v210: (byte 0) */
  HW(1,1)
, 0
,	/* F0_LAMBDA201: (byte 0) */
  CAPTAG(useLabel(FN_LAMBDA201),1)
, VAPTAG(useLabel(FN_Prelude_46Monad_46NHC_46Internal_46IO_46return))
,	/* ST_v205: (byte 0) */
  bytes2word(78,72,67,46)
, bytes2word(66,105,110,65)
, bytes2word(114,114,97,121)
, bytes2word(46,104,115,95)
, bytes2word(114,85,66,65)
,	/* ST_v203: (byte 1) */
  bytes2word(0,78,72,67)
, bytes2word(46,66,105,110)
, bytes2word(65,114,114,97)
, bytes2word(121,46,104,115)
, bytes2word(95,114,85,66)
,	/* ST_v207: (byte 3) */
  bytes2word(65,35,0,78)
, bytes2word(72,67,46,66)
, bytes2word(105,110,65,114)
, bytes2word(114,97,121,46)
, bytes2word(114,85,66,65)
,	/* ST_v209: (byte 1) */
  bytes2word(0,78,72,67)
, bytes2word(46,66,105,110)
, bytes2word(65,114,114,97)
, bytes2word(121,46,114,85)
, bytes2word(66,65,58,49)
, bytes2word(53,58,49,52)
, bytes2word(45,49,53,58)
, bytes2word(50,56,0,0)
,};

#include <haskell2c.h>
#include <HsFFI.h>

/* foreign import ccall "hs_rUBA" NHC.BinArray.hs_rUBA# 2 :: FFI.ForeignObj -> Prelude.Int -> Prelude.Int */
extern HsInt hs_rUBA(void*,HsInt);
#ifdef PROFILE
static SInfo pf_NHC_46BinArray_46hs_95rUBA_35 = {"NHC.BinArray","NHC.BinArray.hs_rUBA#","Prelude.Int"};
#endif
C_HEADER(FR_NHC_46BinArray_46hs_95rUBA_35) {
  NodePtr nodeptr;
  HsInt result;
  void* arg1;
  HsInt arg2;
  nodeptr = C_GETARG1(1);
  IND_REMOVE(nodeptr);
  arg1 = (void*)derefForeignObj((ForeignObj*)GET_INT_VALUE(nodeptr));
  nodeptr = C_GETARG1(2);
  IND_REMOVE(nodeptr);
  arg2 = (HsInt)GET_INT_VALUE(nodeptr);

  result = hs_rUBA(arg1,arg2);

  nodeptr = nhc_mkInt(result);
  INIT_PROFINFO(nodeptr,&pf_NHC_46BinArray_46hs_95rUBA_35);
  C_RETURN(nodeptr);
}
